@@ -82,7 +82,8 @@ class Project:
             pipfile = Pipfile.from_file(pipfile_path)
         except Exception as exc:
             raise FileLoadError(
-                f"Failed to load Pipfile (path: {os.getcwd() if not pipfile_path else pipfile_path}: {str(exc)}"
+                "Failed to load Pipfile (path: "
+                f"{os.getcwd() if not pipfile_path else os.path.abspath(pipfile_path)}: {str(exc)}"
             ) from exc
 
         pipfile_lock = None
@@ -92,7 +93,7 @@ class Project:
             except Exception as exc:
                 raise FileLoadError(
                     f"Failed to load Pipfile.lock "
-                    f"(path: {os.getcwd() if not pipfile_lock_path else pipfile_lock_path}: {str(exc)}"
+                    f"(path: {os.getcwd() if not pipfile_lock_path else os.path.abspath(pipfile_lock_path)}: {str(exc)}"
                 ) from exc
 
         return cls(
